# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Forum'
        db.create_table('rforum_forum', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('slug', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('description', self.gf('django.db.models.fields.TextField')(default='', blank=True)),
            ('date_created', self.gf('django.db.models.fields.DateTimeField')()),
            ('date_modified', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('post_count', self.gf('django.db.models.fields.IntegerField')(default=0, blank=True)),
            ('topic_count', self.gf('django.db.models.fields.IntegerField')(default=0, blank=True)),
            ('order', self.gf('django.db.models.fields.IntegerField')(default=0, blank=True)),
            ('status', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('visible', self.gf('django.db.models.fields.BooleanField')(default=True)),
        ))
        db.send_create_signal('rforum', ['Forum'])

        # Adding M2M table for field moderators on 'Forum'
        db.create_table('rforum_forum_moderators', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('forum', models.ForeignKey(orm['rforum.forum'], null=False)),
            ('user', models.ForeignKey(orm['auth.user'], null=False))
        ))
        db.create_unique('rforum_forum_moderators', ['forum_id', 'user_id'])

        # Adding model 'Topic'
        db.create_table('rforum_topic', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(related_name='topics', to=orm['auth.User'])),
            ('forum', self.gf('django.db.models.fields.related.ForeignKey')(related_name='topics', to=orm['rforum.Forum'])),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('slug', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('date_created', self.gf('django.db.models.fields.DateTimeField')()),
            ('date_modified', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('post_count', self.gf('django.db.models.fields.IntegerField')(default=0, blank=True)),
            ('topic_count', self.gf('django.db.models.fields.IntegerField')(default=0, blank=True)),
            ('hits', self.gf('django.db.models.fields.IntegerField')(default=1, blank=True)),
            ('status', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('sticky', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('closed', self.gf('django.db.models.fields.BooleanField')(default=False)),
        ))
        db.send_create_signal('rforum', ['Topic'])

        # Adding M2M table for field subscribers on 'Topic'
        db.create_table('rforum_topic_subscribers', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('topic', models.ForeignKey(orm['rforum.topic'], null=False)),
            ('user', models.ForeignKey(orm['auth.user'], null=False))
        ))
        db.create_unique('rforum_topic_subscribers', ['topic_id', 'user_id'])

        # Adding model 'Post'
        db.create_table('rforum_post', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(related_name='posts', to=orm['auth.User'])),
            ('topic', self.gf('django.db.models.fields.related.ForeignKey')(related_name='posts', to=orm['rforum.Topic'])),
            ('date_created', self.gf('django.db.models.fields.DateTimeField')()),
            ('date_modified', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('body', self.gf('django.db.models.fields.TextField')()),
            ('status', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('user_ip', self.gf('django.db.models.fields.IPAddressField')(max_length=15, null=True, blank=True)),
        ))
        db.send_create_signal('rforum', ['Post'])

        # Adding model 'UserProfile'
        db.create_table('rforum_userprofile', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(related_name='profile', unique=True, to=orm['auth.User'])),
            ('twitter', self.gf('django.db.models.fields.CharField')(max_length=55, blank=True)),
            ('avatar', self.gf('django.db.models.fields.files.ImageField')(max_length=100, blank=True)),
            ('signature', self.gf('django.db.models.fields.TextField')(default='', blank=True)),
        ))
        db.send_create_signal('rforum', ['UserProfile'])

        # Adding model 'Rank'
        db.create_table('rforum_rank', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('limit_from', self.gf('django.db.models.fields.IntegerField')(default=1, blank=True)),
            ('limit_to', self.gf('django.db.models.fields.IntegerField')(default=1, blank=True)),
            ('rank', self.gf('django.db.models.fields.CharField')(max_length=80, blank=True)),
        ))
        db.send_create_signal('rforum', ['Rank'])


    def backwards(self, orm):
        # Deleting model 'Forum'
        db.delete_table('rforum_forum')

        # Removing M2M table for field moderators on 'Forum'
        db.delete_table('rforum_forum_moderators')

        # Deleting model 'Topic'
        db.delete_table('rforum_topic')

        # Removing M2M table for field subscribers on 'Topic'
        db.delete_table('rforum_topic_subscribers')

        # Deleting model 'Post'
        db.delete_table('rforum_post')

        # Deleting model 'UserProfile'
        db.delete_table('rforum_userprofile')

        # Deleting model 'Rank'
        db.delete_table('rforum_rank')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'rforum.forum': {
            'Meta': {'ordering': "['order']", 'object_name': 'Forum'},
            'date_created': ('django.db.models.fields.DateTimeField', [], {}),
            'date_modified': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'default': "''", 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'moderators': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['auth.User']", 'null': 'True', 'blank': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'default': '0', 'blank': 'True'}),
            'post_count': ('django.db.models.fields.IntegerField', [], {'default': '0', 'blank': 'True'}),
            'slug': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'status': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'topic_count': ('django.db.models.fields.IntegerField', [], {'default': '0', 'blank': 'True'}),
            'visible': ('django.db.models.fields.BooleanField', [], {'default': 'True'})
        },
        'rforum.post': {
            'Meta': {'ordering': "['date_created']", 'object_name': 'Post'},
            'body': ('django.db.models.fields.TextField', [], {}),
            'date_created': ('django.db.models.fields.DateTimeField', [], {}),
            'date_modified': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'status': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'topic': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'posts'", 'to': "orm['rforum.Topic']"}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'posts'", 'to': "orm['auth.User']"}),
            'user_ip': ('django.db.models.fields.IPAddressField', [], {'max_length': '15', 'null': 'True', 'blank': 'True'})
        },
        'rforum.rank': {
            'Meta': {'object_name': 'Rank'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'limit_from': ('django.db.models.fields.IntegerField', [], {'default': '1', 'blank': 'True'}),
            'limit_to': ('django.db.models.fields.IntegerField', [], {'default': '1', 'blank': 'True'}),
            'rank': ('django.db.models.fields.CharField', [], {'max_length': '80', 'blank': 'True'})
        },
        'rforum.topic': {
            'Meta': {'ordering': "['-sticky', '-date_modified']", 'object_name': 'Topic'},
            'closed': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'date_created': ('django.db.models.fields.DateTimeField', [], {}),
            'date_modified': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'forum': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'topics'", 'to': "orm['rforum.Forum']"}),
            'hits': ('django.db.models.fields.IntegerField', [], {'default': '1', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'post_count': ('django.db.models.fields.IntegerField', [], {'default': '0', 'blank': 'True'}),
            'slug': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'status': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'sticky': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'subscribers': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['auth.User']", 'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'topic_count': ('django.db.models.fields.IntegerField', [], {'default': '0', 'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'topics'", 'to': "orm['auth.User']"})
        },
        'rforum.userprofile': {
            'Meta': {'object_name': 'UserProfile'},
            'avatar': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'signature': ('django.db.models.fields.TextField', [], {'default': "''", 'blank': 'True'}),
            'twitter': ('django.db.models.fields.CharField', [], {'max_length': '55', 'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'profile'", 'unique': 'True', 'to': "orm['auth.User']"})
        }
    }

    complete_apps = ['rforum']


# -*- coding: utf-8 -*-

from django import template
from django.utils.translation import ugettext as _
from django.template.loader import render_to_string
from django.conf import settings as conf
from django.contrib.auth.models import User
import datetime
import random
import rforum.models as mymodels

register = template.Library()

@register.inclusion_tag('rforum/elements/widget_lastposts.html')
def last_posts(num):

    """
    Simple posts list
    """
    lastposts = mymodels.Post.objects.filter(status=1).order_by('-id')[:num]
    return { 'lastposts': lastposts }


@register.inclusion_tag('rforum/elements/widget_lastnews.html')
def last_news(num):

    """
    Last topics list
    """
    forum = mymodels.Forum.objects.filter(status=1,visible=1,slug=conf.NEWS_FORUM).order_by('-id')
    topics = mymodels.Topic.objects.filter(forum=forum).order_by('-id')[:num]
    return { 'topics': topics }


@register.inclusion_tag('rforum/elements/widget_onlineusers.html')
def online_users(num):
    """
    Show user that has been login an hour ago.
      - http://djangosnippets.org/snippets/947/
      - http://mpcabd.igeex.biz/get-online-users-in-django/ (better implementation)
    """
    one_hour_ago = datetime.datetime.now() - datetime.timedelta(hours=1)
    sql_datetime = datetime.datetime.strftime(one_hour_ago, '%Y-%m-%d %H:%M:%S')

    if "rauthall" in conf.INSTALLED_APPS:
        from allauth.account.models import EmailAddress
        #users = [ea.user for ea in EmailAddress.objects.filter(verified=True).filter(user__last_login__gt=sql_datetime,
        #                        user__is_active=True).order_by('-last_login')[:num]]
        users = User.objects.filter(last_login__gt=sql_datetime,
                                    is_active__exact=1).order_by('-last_login')[:num]
    else:
        users = User.objects.filter(last_login__gt=sql_datetime,
                                    is_active__exact=1).order_by('-last_login')[:num]
    return { 'users': users, 'anon': random.randrange(60,78,1) }

@register.inclusion_tag('rforum/elements/widget_lastregisters.html')
def last_registers(num):
    """
    Show last registered users.

        authall.account.models
        >>> from django.contrib.auth.models import User
        >>> users = User.objects.filter(is_active__exact=1).order_by('-date_joined')
        >>> users
        [<User: pepe>, <User: wrerw>, <User: oscar>, <User: admin>]
        >>> from allauth.account.models import EmailAddress

        # up = get_object_or_404(rmodels.UserProfile, user=get_object_or_404(User, username=self.kwargs['user']))
    """
    if "rauthall" in conf.INSTALLED_APPS:
        from allauth.account.models import EmailAddress
        users = [ea.user for ea in EmailAddress.objects.filter(verified=True).filter(user__is_active=True)]
    else:
        users = User.objects.filter(is_active=True).order_by('-date_joined')[:num]
    return { 'users': users }

@register.inclusion_tag('rforum/elements/widget_lastlogins.html')
def last_logins(num):
    """
    Show last logins ...
    """
    if "rauthall" in conf.INSTALLED_APPS:
        from allauth.account.models import EmailAddress
        users = [ea.user for ea in EmailAddress.objects.filter(verified=True).filter(user__is_active=True)]
    else:
        users = User.objects.filter(is_active__exact=1).order_by('-last_login')[:num]
    return { 'users': users }


@register.inclusion_tag('rforum/elements/widget_stats.html')
def stats():
    """
    Show forum stats...
    """
    numposts = mymodels.Post.objects.filter(status=1)
    numtopics = mymodels.Topic.objects.all()

    if "rauthall" in conf.INSTALLED_APPS:
        from allauth.account.models import EmailAddress
        numusers = len([ea.user for ea in EmailAddress.objects.filter(verified=True).filter(user__is_active=True)])
    else:
        numusers = User.objects.filter(is_active__exact=1).count

    return { 'numusers': numusers, 'numposts': numposts.count, 'numtopics': numtopics.count, }



# -*- coding: utf-8 -*-

"""
Models for the "forum" project
"""

import time
import socket
from django.db import models
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes import generic
from django.template.defaultfilters import slugify
from datetime import datetime

class Forum(models.Model):

    """
    Forum model
    """

    moderators = models.ManyToManyField(User, blank=True, null=True, verbose_name=_('Moderators'))
    title = models.CharField(_('Title'), max_length=255)
    slug = models.CharField(_('Slug'), max_length=200)
    description = models.TextField(_('Description'), blank=True, default='')
    date_created = models.DateTimeField(_('Date Created'))
    date_modified = models.DateTimeField(_('Date Modified'),auto_now_add=True)
    post_count = models.IntegerField(_('Post count'), blank=True, default=0)
    topic_count = models.IntegerField(_('Topic count'), blank=True, default=0)
    order = models.IntegerField(_('Order'), blank=True, default=0)
    status =  models.BooleanField(_('Status'), default=True)
    visible =  models.BooleanField(_('Visible'), default=True)

    def __unicode__(self):
        return self.slug

    class Meta:
        ordering = ['order']
        verbose_name = _('Forum')
        verbose_name_plural = _('Forums')


class Topic(models.Model):

    """
    Topic model
    """

    user = models.ForeignKey(User, related_name="topics")
    forum = models.ForeignKey(Forum, related_name='topics', verbose_name=_('Forum'))
    title = models.CharField(_('Title'), max_length=255)
    slug = models.CharField(_('Slug'), max_length=200)
    date_created = models.DateTimeField(_('Date Created'))
    date_modified = models.DateTimeField(_('Date Modified'),auto_now_add=True)
    post_count = models.IntegerField(_('Post count'), blank=True, default=0)
    topic_count = models.IntegerField(_('Topic count'), blank=True, default=0)
    hits = models.IntegerField(_('Hits'), blank=True, default=1)
    status =  models.BooleanField(_('Status'), default=True)
    sticky = models.BooleanField(_('Sticky'), blank=True, default=False)
    closed = models.BooleanField(_('Closed'), blank=True, default=False)
    subscribers = models.ManyToManyField(User, blank=True, null=True, verbose_name=_('Subscribers'))

    def __unicode__(self):
        return "%s (%s)"%(self.slug, self.forum)

    def save(self, *args, **kwargs):
        self.date_modified = datetime.now()
        super(Topic, self).save()

    def add_subscriber(self, myuser):
        self.subscribers.add(myuser)

    def del_subscriber(self, myuser):
        self.subscribers.delete(myuser)

    class Meta:
        ordering = ['-sticky', '-date_modified']
        verbose_name = _('Topic')
        verbose_name_plural = _('Topics')


class Post(models.Model):

    """
    Post model
    """

    user = models.ForeignKey(User, related_name="posts")
    topic = models.ForeignKey(Topic, related_name='posts', verbose_name=_('Topic'))
    date_created = models.DateTimeField(_('Date Created'))
    date_modified = models.DateTimeField(_('Date Modified'),auto_now_add=True)
    body = models.TextField(_('Message'))
    status =  models.BooleanField(_('Status'), default=True)
    user_ip = models.IPAddressField(_('User IP'), blank=True, null=True)

    def __unicode__(self):
        return self.body

    def save(self, *args, **kwargs):
        self.user_ip = socket.gethostbyname(socket.gethostname())
        self.date_modified = datetime.now()
        super(Post, self).save()

    class Meta:
        ordering = ['date_created']
        verbose_name = _('Post')
        verbose_name_plural = _('Posts')


class Rank(models.Model):

    """
    Rank model
    """

    limit_from = models.IntegerField(_('Limit from'), blank=True, default=1)
    limit_to = models.IntegerField(_('Limit to'), blank=True, default=1)
    rank = models.CharField(_('Rank name'), max_length=80, blank=True)

    class Meta:
        verbose_name = _('Ranking')
        verbose_name_plural = _('Rankings')

    def __unicode__(self):
        return self.rank



# -*- coding: utf-8 -*-
import models as mymodels
import utils
from django.shortcuts import get_object_or_404, render_to_response
from django.shortcuts import redirect
from django.contrib import messages
from django.utils.translation import ugettext_lazy as _

class IsModerator(object):

    def process_view(self, request,view_func,view_args,view_kwargs):

        """
        Debug time: Aquí paramos el código para ver las variables de entorno
                    que nos encontramos, tenemos varias opciones:
                    l - Nos muestra el número de linea en la que estamos
                    n - Salta a la siguiente linea de ejecución
                    p dir(var) - Muestra todos los métodos de la variable dir
                    var - Es como hacer un "print" de la variable, muestra su
                          contenido.
        """
        #import pdb; pdb.set_trace()

        """ Devuelve True o False """

        #print request
        #print request.user
        #print view_func.__name__
        #print view_kwargs['slug']
        #print view_kwargs

        # request.user: AnonymousUser
        # view_func.__name__: TopicDelete
        # view_kwargs: {'topicslug': u'primer-partido-20132014-lugo-numancia'}
        # [20/Aug/2013 12:55:27] "GET /foro-cdlugo/delete-topic/primer-partido-20132014-lugo-numancia/ HTTP/1.1" 302 0

        functionlist = ['PostUpdate', 'PostDelete', 'TopicAction', 'TopicDelete']

        try:
            if view_func.__name__ in functionlist:

                if view_kwargs['topicslug'] and view_func.__name__ == 'TopicDelete':
                    if utils.es_moderador(request.user, view_kwargs['topicslug']):
                        return None
                    else:
                        messages.add_message(request, messages.ERROR, _('No puedes eliminar un topic si no eres moderador o admin.'))
                        return redirect('account_profile')

                if view_kwargs['topicslug'] and view_kwargs['id'] and (view_func.__name__ == 'PostUpdate' or view_func.__name__ == 'PostDelete'):
                    if utils.es_suyo(request.user, view_kwargs['id']):
                        return None
                    else:
                        messages.add_message(request, messages.ERROR, _('No puedes editar o eliminar un post que no es tuyo.'))
                        return redirect('account_profile')

                    if utils.es_moderador(request.user, view_kwargs['topicslug']):
                        return None
                    else:
                        messages.add_message(request, messages.ERROR, _('No eres moderador, cuidado con lo que haces.'))
                        return redirect('account_profile')
        except:
            return None

        return None



# -*- coding: utf-8 -*-

from django.conf.urls.defaults import *
from rforum.views import *

"""
Todas las llamadas que lleven un argumento 'topicslug' pasan por un middleware
(siempre que esté configurado en settings) que comprueba si el usuario activo
tiene permisos de administrador para el Forum de ese Topic, así nos aseguramos
de que nunca se pasen por alto los permisos de moderadores.

Por defecto los administradores también son moderadores. Ojo, porque si en
alguna acción que tenga que pasar por middleware no llamamos "topicslug" al
parámetro, no pasará.
"""

urlpatterns = patterns('',
    url(r'^$',                     ForumListView.as_view(), {}, 'app_forum-forum-index'),
    url(r'^(?P<slug>[-\w]+)/$',    ForumDetailView.as_view(), {}, "app_forum-forum-detail"),

    url(r'^(?P<slug>[-\w]+)/(?P<slug2>[-\w]+).html$',                  TopicListView.as_view(), {}, "app_forum-topic-list"),
    url(r'^add-topic/(?P<slug>[-\w]+)/$',                              TopicCreate.as_view(), {}, "app_forum-topic-add"),
    url(r'^openclose-topic/(?P<topicslug>[-\w]+)/(?P<action>[-\w]+)$', TopicAction.as_view(), {}, "app_forum-topic-action"), # topicslug, pasa por middleware
    url(r'^delete-topic/(?P<topicslug>[-\w]+)/$',                      TopicDelete.as_view(), {}, "app_forum-topic-delete"), # topicslug, pasa por middleware

    url(r'^add-post/(?P<slug>[-\w]+)/$',                        PostCreate.as_view(), {}, "app_forum-post-add"),
    url(r'^edit-post/(?P<topicslug>[-\w]+)/(?P<id>[-\w]+)$',    PostUpdate.as_view(), {}, "app_forum-post-edit"),   # topicslug, pasa por middleware
    url(r'^delete-post/(?P<topicslug>[-\w]+)/(?P<id>[-\w]+)$',  PostDelete.as_view(), {}, "app_forum-post-delete"), # topicslug, pasa por middleware
    url(r'^report-post/(?P<topicslug>[-\w]+)/(?P<id>[-\w]+)$',    PostReportInnapropiate, {}, "app_forum-post-reportinnapropiate"),   # topicslug, pasa por middleware

    url(r'^user/(?P<user>[-\w]+)/$',                            UserProfileView.as_view(), {}, "app_forum-userprofile"),

)
